
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef play_MSG_LIB_H
#define play_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "playType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  PLAY_MBOX_NAME                  genomInstanceName("play")

#define  PLAY_MAX_RQST_SIZE              72

#define  PLAY_MBOX_RQST_SIZE       \
 (BUF_SIZE(PLAY_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  PLAY_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  PLAY_MAX_REPLY_SIZE             72

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  PLAY_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(PLAY_MAX_REPLY_SIZE) \
   + BUF_SIZE(PLAY_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define PLAY_CONNECT_RQST 0
#define PLAY_GETCONNECT_RQST 1
#define PLAY_GETSTATUS_RQST 2
#define PLAY_MOTORS_RQST 3
#define PLAY_SPEEDREF_RQST 4
#define PLAY_STOP_RQST 5
#define PLAY_TRACKSPEED_RQST 6
#define PLAY_SONARS_RQST 7
#define PLAY_BUMPERS_RQST 8
#define PLAY_LASER_RQST 9
#define PLAY_ABORT_RQST 10


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS playClientInit (CLIENT_ID *pClientId);

STATUS playClientEnd (CLIENT_ID clientId);

int playAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int playAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int playAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS playConnectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLAY_CONNECT *(in_connect),
					 int replyTimeOut);

extern int playConnectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int playConnectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLAY_CONNECT *(in_connect), 
					
					int *activity, int *bilan);

extern int playConnectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLAY_CONNECT *(in_connect), 
					
					int *activity,
					int *bilan);




extern STATUS playGetConnectRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int playGetConnectReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       PLAY_CONNECT *(out_connect),
			       int *bilan);

int playGetConnectRqstAndRcv (CLIENT_ID clientId, 
				  
				 PLAY_CONNECT *(out_connect),
				 int *bilan);




extern STATUS playGetStatusRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 PLAY_STATUS *(in_status),
					 int replyTimeOut);

int playGetStatusReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int playGetStatusRqstAndRcv (CLIENT_ID clientId, 
				 PLAY_STATUS *(in_status), 
				 
				 int *bilan);




extern STATUS playMotorsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLAY_BOOL *(in_motorsFlag),
					 int replyTimeOut);

extern int playMotorsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int playMotorsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLAY_BOOL *(in_motorsFlag), 
					
					int *activity, int *bilan);

extern int playMotorsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLAY_BOOL *(in_motorsFlag), 
					
					int *activity,
					int *bilan);




extern STATUS playSpeedRefRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLAY_SPEED *(in_speedRef),
					 int replyTimeOut);

extern int playSpeedRefReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int playSpeedRefRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLAY_SPEED *(in_speedRef), 
					
					int *activity, int *bilan);

extern int playSpeedRefRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLAY_SPEED *(in_speedRef), 
					
					int *activity,
					int *bilan);




extern STATUS playStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int playStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int playStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS playTrackSpeedRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING64 *(in_trackPoster),
					 int replyTimeOut);

extern int playTrackSpeedReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int playTrackSpeedRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING64 *(in_trackPoster), 
					
					int *activity, int *bilan);

extern int playTrackSpeedRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING64 *(in_trackPoster), 
					
					int *activity,
					int *bilan);




extern STATUS playSonarsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLAY_BOOL *(in_sonarsFlag),
					 int replyTimeOut);

extern int playSonarsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int playSonarsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLAY_BOOL *(in_sonarsFlag), 
					
					int *activity, int *bilan);

extern int playSonarsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLAY_BOOL *(in_sonarsFlag), 
					
					int *activity,
					int *bilan);




extern STATUS playBumpersRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int playBumpersReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      int *(out_bumperNum),
				      int *activity, int *bilan);


extern int playBumpersRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					int *(out_bumperNum),
					int *activity, int *bilan);

extern int playBumpersRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					int *(out_bumperNum),
					int *activity,
					int *bilan);




extern STATUS playLaserRqstSend (CLIENT_ID clientId, int *pRqstId,
					 PLAY_BOOL *(in_laserFlag),
					 int replyTimeOut);

extern int playLaserReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int playLaserRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					PLAY_BOOL *(in_laserFlag), 
					
					int *activity, int *bilan);

extern int playLaserRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					PLAY_BOOL *(in_laserFlag), 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* play_MSG_LIB_H */

